name := "tiny"

version := "0.1"

scalaVersion := "2.12.8"

// Java CUP runner
val java_cup = taskKey[Unit]("Run Java CUP on roost.cup.")

// JFlex runner
val jflex = taskKey[Unit]("Run JFlex on roost.flex.")

// Lexer/parser generators
val generators = taskKey[Unit]("Run lexer/parser generators.")
val dump = taskKey[Unit]("Run CUP with -dump to show automaton and tables.")

import scala.sys.process._
lazy val root = (project in file("."))
  .settings(
    java_cup := {
      val result: Int = "java -jar ./lib/java-cup-11b.jar -destdir ./src/main/scala/tiny -expect 1 ./src/main/scala/tiny/tiny.cup".!
      if (result != 0) {
        sys.error("Java CUP failed.")
      }
    },
    jflex := {
      val javaCupRun = java_cup.value
      val result: Int = "java -jar ./lib/jflex-full-1.7.0.jar -d ./src/main/scala/tiny ./src/main/scala/tiny/tiny.flex".!
      if (result != 0) {
        sys.error("JFlex failed.")
      }
    },
    generators := {
      val jflexRun = jflex.value
      (Compile / compile).value
    },
    dump := {
      val result: Int = "java -jar ./lib/java-cup-11b.jar -destdir ./src/main/scala/tiny -dump ./src/main/scala/tiny/tiny.cup".!
      if (result != 0) {
        sys.error("Java CUP failed.")
      }
    }
  )

// Make lexer/parser generators a prereq for the build.
(Compile / compile) := ((Compile / compile) dependsOn jflex).value