package tiny;

import java_cup.runtime.*;

%%
%class Lexer
%public
%cup
%line
%column

%{
  /** Create a token with the given type and the given value */
  Symbol create(int type, Object value) {
    return new Symbol(type, yyline+1, yyline+1, value);
  }

  /** Create a token with the given type and no value */
  Symbol create(int type) {
    return create(type, null);
  }
%}

%%

/* keywords */
"print"     { return create(sym.PRINT); }
"input"     { return create(sym.INPUT); }
"="         { return create(sym.EQ); }
"+"         { return create(sym.PLUS); }
";"         { return create(sym.SEMI); }
"("         { return create(sym.LPAREN); }
")"         { return create(sym.RPAREN); }

/* identifiers */
[:letter:]+       { return create(sym.ID, yytext()); }
"-"?[:digit:]+    { return create(sym.NUM, new Integer(yytext())); }

/* whitespace */
[ \t\n]      { /* ignore */ }

/* error fallback */
/* .|\n         { throw new LexicalError(yyline+1, "Illegal character '" + yytext() + "'"); } */

